# 📖 Summary
- [📖 Summary](#📖-summary)
- [💼 About Hubspot](#💼-about-hubspot)
  - [😍 Why is it a big deal for Hubspot customers & partners?](#😍-why-is-it-a-big-deal-for-hubspot-customers--partners)
- [🔧 How does it work?](#🔧-how-does-it-work)
  - [📊 Data integration capabilities:](#📊-data-integration-capabilities)
  - [🧠 Artificial Intelligence capabilities:](#🧠-artificial-intelligence-capabilities)
- [🔌 Connector Actions](#🔌-connector-actions)
- [💍 Quick Start Examples](#💍-quick-start-examples)
- [🔗 Useful Links](#🔗-useful-links)
- [👏 Special Thanks](#👏-special-thanks)


# 💼 About Hubspot

> HubSpot is a CRM platform with all the software, integrations, and resources you need to connect marketing, sales, content management, and customer service.


## 😍 Why is it a big deal for Hubspot customers & partners?

This new connector will enable:
- ⚡ A Fastlane Talent & Workforce data integration for Hubspot customers & partners
- 🤖 Cutting-edge AI-powered Talent Experiences & Recruiter Experiences for Hubspot customers

#  🔧 How does it work?
## 📊 Data integration capabilities:
- ⬅️ Send Profiles data from Hubspot to a Destination of your choice.
- ➡️ Send Profiles data from a Source of your choice to Hubspot.
- ⬅️ Send Jobs data from Hubspot to a Destination of your choice.
- ➡️ Send Jobs data from a Source of your choice to Hubspot.

<p align="center">

<image src=https://user-images.githubusercontent.com/107410704/213676477-70dd9009-f41b-4659-a58c-41f53a92f7d4.jpg width=90% height=100% >
</p>

## 🧠 Artificial Intelligence capabilities:
- Extract, Structure, and Categorize Talent & Workforce data
- Search, Score, and Match Profiles & Jobs with our APIs and AI Widgets (**Matching Custom Tab in Hubspot**)


# 🔌 Connector Actions
<p align="center">

| Action | Description |
| ------- | ----------- |
| [**Create profiles in hrflow**](docs/create_profiles_in_hrflow.md) | Send **created** 'profile(s)' _from_  _to_ HrFlow |
| [**Create profiles in **](docs/create_profiles_in_.md) | Send **created** 'profile(s)' _from_ HrFlow _to_  |
| [**Update profiles in hrflow**](docs/update_profiles_in_hrflow.md) | Send **updated** 'profile(s)' _from_  _to_ HrFlow |
| [**Update profiles in **](docs/update_profiles_in_.md) | Send **updated** 'profile(s)' _from_ HrFlow _to_  |
| [**Archive profiles in hrflow**](docs/archive_profiles_in_hrflow.md) | Send **archived** 'profile(s)' _from_  _to_ HrFlow |
| [**Archive profiles in **](docs/archive_profiles_in_.md) | Send **archived** 'profile(s)' _from_ HrFlow _to_  |


</p>


# 💍 Quick Start Examples

To make sure you can successfully run the latest versions of the example scripts, you have to **install the package from PyPi**.


To browse the examples of actions corresponding to released versions of 🤗 this connector, you just need to import the module like this :


<p align="center">
<image src=https://user-images.githubusercontent.com/107410704/219017227-8e7f86a6-fd8d-4e31-ab07-5ef13184eab0.png width=90% height=100% >
</p>

Once the connector module is imported, you can leverage all the different actions that it offers.

For more code details checkout connector code.


# 🔗 Useful Links

- 📄Visit [Hubspot](https://www.hubspot.com) to learn more.
- ⚙️ API documentation : (https://developers.hubspot.com/docs/api/overview)
- 💻 [Connector code](https://github.com/Riminder/hrflow-connectors/tree/master/src/hrflow_connectors/v2/connectors/hubspot) on our Github.


# 👏 Special Thanks
- 💻 HrFlow.ai :  [Nedhir Ebnou](https://github.com/itsnedhir) - Software Engineer
- 🤝 Hubspot :[Hubspot for the  accessible documentation](https://www.hubspot.com)

